.. _recipe_asr.chc:

asr.chc
=======


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.chc`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.chc.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.chc

or as a python module

.. code-block:: console

   $ python -m asr.chc


Steps
-----


asr.chc
^^^^^^^
.. autofunction:: asr.chc.main
   